@@ -61,13 +61,15 @@ static QString qt2KdeFilter(const QStringList &f)
         int ob = it->lastIndexOf(QLatin1Char('(')),
             cb = it->lastIndexOf(QLatin1Char(')'));
 
+        if (first) {
+            first = false;
+        } else {
+            str << '\n';
+        }
         if (-1 != cb && ob < cb) {
-            if (first) {
-                first = false;
-            } else {
-                str << '\n';
-            }
             str << it->mid(ob + 1, (cb - ob) - 1) << '|' << it->mid(0, ob);
+        } else {
+            str << (*it);
         }
     }
 
@@ -127,7 +129,7 @@ void KDEPlatformFileDialog::selectFile(const QUrl &filename)
 {
     QUrl dirUrl = filename.adjusted(QUrl::RemoveFilename);
     m_fileWidget->setUrl(dirUrl);
-    m_fileWidget->setSelection(filename.toString());
+    m_fileWidget->setSelectedUrl(filename);
 }
 
 void KDEPlatformFileDialog::setViewMode(QFileDialogOptions::ViewMode view)
@@ -224,7 +226,7 @@ void KDEPlatformFileDialog::setDirectory(const QUrl &directory)
             if (!entry.isDir()) {
                 // this is probably a file remove the file part
                 m_fileWidget->setUrl(directory.adjusted(QUrl::RemoveFilename));
-                m_fileWidget->setSelection(directory.fileName());
+                m_fileWidget->setSelectedUrl(directory);
             }
             else {
                 m_fileWidget->setUrl(directory);
