@@ -559,6 +559,11 @@ void KDirSelectDialog::setDirectory(const QUrl &directory)
     setCurrentUrl(directory);
 }
 
+QString KDirSelectDialog::selectedMimeTypeFilter()
+{
+    return QString();
+}
+
 QString KDirSelectDialog::selectedNameFilter()
 {
     return QString();
@@ -569,6 +574,11 @@ void KDirSelectDialog::selectFile(const QUrl &filename)
     Q_UNUSED(filename)
 }
 
+void KDirSelectDialog::selectMimeTypeFilter(const QString &filter)
+{
+    Q_UNUSED(filter)
+}
+
 void KDirSelectDialog::selectNameFilter(const QString &filter)
 {
     Q_UNUSED(filter)
